@@ -1,6 +1,7 @@
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
+from statsmodels.tsa.stattools import grangercausalitytests
 
 def fis_variable_frecuency(df_cat):
     """
@@ -151,4 +152,60 @@ def fis_outliers_standard_desv(variable, x = 4):
     lim_sup = media + umbral
     #encontramos los índices de los que están fuera de los límites
     indices = [indice for indice,valor in variable.items() if valor < lim_inf or valor > lim_sup]
-    return(indices)
\ No newline at end of file
+    return(indices)
+    
+# Invirtiendo la transformación
+def fis_TS_invert_transformation(X_train, pred):
+    """
+    Los pronósticos se generan en la escala de los datos de entrenamiento utilizados por el modelo, es decir, son datos transformados. 
+    Entonces, para volver a ponerlos en su escala original, necesitamos des-diferenciarlos.
+    La forma de invertir la diferenciación es sumar estas diferencias consecutivamente al número base. 
+    Una forma sencilla de hacerlo es determinar primero la suma acumulada y luego sumarla al número base.
+    Este proceso se puede revertir agregando la observación en el paso de tiempo anterior al difference value. 
+    inverted(ts) = differenced(ts) + observation(ts-1)
+    
+    Retrocede una aplicación de:
+    ----------------------------
+    X_train_transformed=X_train.diff().dropna()
+    X_train_transformed.head()
+    """
+  forecast = pred.copy()
+  columns = X_train.columns
+  for col in columns:
+    forecast[str(col)+'_pred'] = X_train[col].iloc[-1] + forecast[str(col)+'_pred'].cumsum()
+  return forecast
+  
+
+def fis_TS_grangers_causality_matrix(X_train_transformed, variables, test = 'ssr_chi2test', verbose=False,maxlag=15):
+    """
+    Causalidad de Granger (Wiener-Granger)
+    
+    Ejemplo:
+    --------
+    grangers_causality_matrix(X_train_transformed, variables = X_train_transformed.columns)
+    """
+  dataset = pd.DataFrame(np.zeros((len(variables), len(variables))), columns=variables, index=variables)
+  for c in dataset.columns:
+    for r in dataset.index:
+      test_result = grangercausalitytests(X_train_transformed[[r,c]], maxlag=maxlag, verbose=False)
+      p_values = [round(test_result[i+1][0][test][1],4) for i in range(maxlag)]
+      if verbose: 
+        print(f'Y = {r}, X = {c}, P Values = {p_values}')
+      min_p_value = np.min(p_values)
+      dataset.loc[r,c] = min_p_value
+  dataset.columns = [var + '_x' for var in variables]
+  dataset.index = [var + '_y' for var in variables]
+  return dataset
+  
+def fis_TS_dickey_fuller_statistics(X_train):
+    """
+    Dickey Fuller test, para diferentes columnas de un DataFrame que correspondan a series temporales.
+    Si los p-valores son mayores que 0.05, No se rechaza la hipótesis nula de que la serie no es estacionaria. 
+    Habría que transformar los datos porque no se puede confirmar estacionariedad.
+    """
+  print('Augmented Dickey-Fuller Test:')
+  for column in X_train.columns:
+    result = sts.adfuller(X_train[column].values)
+    print("Temporal Serie for: ",column)
+    print('p-value: %f' % result[1])
+    print('--------------------------------')
\ No newline at end of file
