@@ -71,8 +71,8 @@ def fis_business_theme():
     white =      "#FFFFFF"
     light_blue = "#DAE3F3"
     silver =     "#D6D7D9"
-    business_colors = ["#D6D7D9",
-                      ]
+    business_colors = ["#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9",
+                    "#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9"]
     sns.set(rc={
         'text.color':dark_blue,
         'axes.labelcolor':dark_blue,
